@@ -35,11 +35,11 @@
 *)
 
 module Make : functor
-  (A : sig
-     type key
-     type value
-   end)
-  -> sig
+    (A : sig
+       type key
+       type value
+     end)
+    -> sig
   (** [new cache finder ?timer size] creates a cache object where [finder]
         is the function responsible for retrieving non-cached data, [timer]
         (if any) is the life span of cached values (in seconds) (values in the
@@ -53,25 +53,21 @@ module Make : functor
         Using [timer] allow one to create a cache
         bounded both in space and time. It is to be noted that real lifespan
         of values is always slightly greater than [timer]. *)
-  class cache :
-    (A.key -> A.value Lwt.t)
-    -> ?timer:float
-    -> int
-    -> object
-         method find : A.key -> A.value Lwt.t
-         (** Find the cached value associated to the key, or binds this
+  class cache : (A.key -> A.value Lwt.t) -> ?timer:float -> int -> object
+    method find : A.key -> A.value Lwt.t
+    (** Find the cached value associated to the key, or binds this
             value in the cache using the function [finder] passed as argument
             to [create], and returns this value *)
 
-         method find_in_cache : A.key -> A.value
-         (** Find the cached value associated to the key. Raises [Not_found]
+    method find_in_cache : A.key -> A.value
+    (** Find the cached value associated to the key. Raises [Not_found]
             if the key is not present in the cache *)
 
-         method remove : A.key -> unit
-         method add : A.key -> A.value -> unit
-         method clear : unit -> unit
-         method size : int
-       end
+    method remove : A.key -> unit
+    method add : A.key -> A.value -> unit
+    method clear : unit -> unit
+    method size : int
+  end
 end
 
 val clear_all_caches : unit -> unit
