@@ -29,7 +29,7 @@ exception Bad_config_tag_for_auth of string
 let register_basic_authentication_method, get_basic_authentication_method =
   let fun_auth =
     ref (fun _config ->
-        raise (Bad_config_tag_for_auth "<unknown basic authentication method>"))
+      raise (Bad_config_tag_for_auth "<unknown basic authentication method>"))
   in
   (* register_basic_authentication_method *)
   ( (fun new_fun_auth ->
@@ -91,7 +91,7 @@ let parse_config element =
         [ Configuration.element ~name:"authbasic"
             ~attributes:
               [ Configuration.attribute ~name:"realm" ~obligatory:true (fun s ->
-                    realm_ref := s) ]
+                  realm_ref := s) ]
             ~other_elements:(fun name attrs content ->
               rest_ref := Xml.Element (name, attrs, content) :: !rest_ref)
             () ]
@@ -104,18 +104,11 @@ let parse_config element =
   in
   gen ~realm ~auth
 
-(** Registration of the extension *)
+(** Registration of the extension for the config file: *)
 let () =
   Ocsigen_extensions.register ~name:"authbasic"
     ~fun_site:(fun _ _ _ _ _ _ -> parse_config)
     ()
 
-let realm = Ocsigen_server.Site.Config.key ()
-let auth = Ocsigen_server.Site.Config.key ()
-
-let extension =
-  Ocsigen_server.Site.create_extension
-    (fun {Ocsigen_server.Site.Config.accessor} ->
-      match accessor realm, accessor auth with
-      | Some realm, Some auth -> gen ~realm ~auth
-      | _, _ -> failwith "Authbasic realm and/or auth not set")
+(** Instruction for static linking without config file: *)
+let run ~realm ~auth () _ _ _ = gen ~realm ~auth
