@@ -104,9 +104,9 @@ let parse_config element =
               ; Configuration.attribute ~name:"url" (fun s -> dest := Some s)
               ; Configuration.attribute ~name:"dest" (fun s -> dest := Some s)
               ; Configuration.attribute ~name:"fullrewrite" (fun s ->
-                    fullrewrite := s = "fullrewrite" || s = "true")
+                  fullrewrite := s = "fullrewrite" || s = "true")
               ; Configuration.attribute ~name:"continue" (fun s ->
-                    continue := s = "continue" || s = "true") ]
+                  continue := s = "continue" || s = "true") ]
             () ]
       element);
   match !dest with
@@ -127,3 +127,11 @@ let () =
   Ocsigen_extensions.register ~name:"rewritemod"
     ~fun_site:(fun _ _ _ _ _ _ -> parse_config)
     ()
+
+let run ?(continue = false) ?(full_rewrite = false) ~regexp dest () _ _ _ =
+  gen
+    (Regexp
+       ( Ocsigen_lib.Netstring_pcre.regexp ("^" ^ regexp ^ "$")
+       , dest
+       , full_rewrite ))
+    continue
