@@ -51,15 +51,15 @@ val remove : path:Ocsigen_lib_base.Url_base.path -> string -> t -> t
 (** Polymorphic versions of [add] and [remove] to use when we don't need to
     OUnset (client-side) *)
 module Poly : sig
-  val add
-    :  path:Ocsigen_lib_base.Url_base.path
+  val add :
+     path:Ocsigen_lib_base.Url_base.path
     -> string
     -> 'a
     -> 'a Map_inner.t Map_path.t
     -> 'a Map_inner.t Map_path.t
 
-  val remove
-    :  path:Ocsigen_lib_base.Url_base.path
+  val remove :
+     path:Ocsigen_lib_base.Url_base.path
     -> string
     -> 'a Map_inner.t Map_path.t
     -> 'a Map_inner.t Map_path.t
