@@ -58,8 +58,8 @@ type virtual_hosts = (string * Re.Pcre.regexp * int option) list
 val hash_virtual_hosts : virtual_hosts -> int
 val equal_virtual_hosts : virtual_hosts -> virtual_hosts -> bool
 
-val host_match
-  :  virtual_hosts:virtual_hosts
+val host_match :
+   virtual_hosts:virtual_hosts
   -> host:string option
   -> port:int
   -> bool
@@ -91,16 +91,16 @@ type config_info =
   ; mime_assoc : Ocsigen_charset_mime.mime_assoc
   ; charset_assoc : Ocsigen_charset_mime.charset_assoc
   ; default_directory_index : string list
-        (** Default name to use as index file when a directory is requested.
+  (** Default name to use as index file when a directory is requested.
       Use [None] if no index should be tried. The various indexes are
       tried in the given order. If no index is specified, or the index
       does not exists, the content of the directory might be listed,
       according to [list_directory_content] *)
   ; list_directory_content : bool
-        (** Should the list of files in a directory be displayed if there is
+  (** Should the list of files in a directory be displayed if there is
       no index in this directory ? *)
   ; follow_symlinks : [`No | `Owner_match | `Always]
-        (** Should symlinks be followed when accessing a local file? *)
+  (** Should symlinks be followed when accessing a local file? *)
   ; do_not_serve_404 : do_not_serve
   ; do_not_serve_403 : do_not_serve
   ; uploaddir : string option
@@ -116,7 +116,7 @@ exception Ocsigen_is_dir of (Ocsigen_request.t -> Uri.t)
 type answer =
   | Ext_do_nothing  (** I don't want to do anything *)
   | Ext_found of (unit -> Ocsigen_response.t Lwt.t)
-      (** "OK stop! I will take the page.  You can start the following
+  (** "OK stop! I will take the page.  You can start the following
       request of the same pipelined connection.  Here is the function
       to generate the page".  The extension must return Ext_found as
       soon as possible when it is sure it is safe to start next
@@ -126,51 +126,51 @@ type answer =
       requests to another server before returning Ext_found, to ensure
       that all requests are done in same order). *)
   | Ext_found_stop of (unit -> Ocsigen_response.t Lwt.t)
-      (** Found but do not try next extensions *)
+  (** Found but do not try next extensions *)
   | Ext_next of Cohttp.Code.status
-      (** Page not found. Try next extension. The status is usually
+  (** Page not found. Try next extension. The status is usually
       `Not_found, but may be for example `Forbidden (403) if you want
       to try another extension afterwards. Same as Ext_continue_with
       but does not change the request. *)
   | Ext_stop_site of (Ocsigen_cookie_map.t * Cohttp.Code.status)
-      (** Error. Do not try next extension, but try next site. *)
+  (** Error. Do not try next extension, but try next site. *)
   | Ext_stop_host of (Ocsigen_cookie_map.t * Cohttp.Code.status)
-      (** Error.
+  (** Error.
       Do not try next extension,
       do not try next site,
       but try next host. *)
   | Ext_stop_all of (Ocsigen_cookie_map.t * Cohttp.Code.status)
-      (** Error. Do not try next extension,
+  (** Error. Do not try next extension,
       do not try next site,
       do not try next host. *)
   | Ext_continue_with of (request * Ocsigen_cookie_map.t * Cohttp.Code.status)
-      (** Used to modify the request before giving it to next extension.
+  (** Used to modify the request before giving it to next extension.
       The extension returns the request (possibly modified) and a set
       of cookies if it wants to set or cookies
-      ({!Ocsigen_cookie_set.empty} for no cookies).  You must add
+      ({!Ocsigen_cookie_map.empty} for no cookies).  You must add
       these cookies yourself in request if you want them to be seen by
       subsequent extensions, for example using
       {!Ocsigen_http_frame.compute_new_ri_cookies}.  The status is
       usually equal to the one received from preceding extension (but
       you may want to modify it). *)
   | Ext_retry_with of request * Ocsigen_cookie_map.t
-      (** Used to retry all the extensions with a new request.  The
+  (** Used to retry all the extensions with a new request.  The
       extension returns the request (possibly modified) and a set of
       cookies if it wants to set or cookies
-      ({!Ocsigen_cookie_set.empty} for no cookies).  You must add
+      ({!Ocsigen_cookie_map.empty} for no cookies).  You must add
       these cookies yourself in request if you want them to be seen by
       subsequent extensions, for example using
       {!Ocsigen_http_frame.compute_new_ri_cookies}. *)
   | Ext_sub_result of extension_composite
-      (** Used if your extension want to define option that may contain
+  (** Used if your extension want to define option that may contain
       other options from other extensions.  In that case, while
       parsing the configuration file, call the parsing function (of
       type [parse_fun]), that will return something of type
       [extension_composite]. *)
   | Ext_found_continue_with of (unit -> (Ocsigen_response.t * request) Lwt.t)
-      (** Same as [Ext_found] but may modify the request. *)
+  (** Same as [Ext_found] but may modify the request. *)
   | Ext_found_continue_with' of (Ocsigen_response.t * request)
-      (** Same as [Ext_found_continue_with] but does not allow to delay
+  (** Same as [Ext_found_continue_with] but does not allow to delay
       the computation of the page. You should probably not use it, but
       for output filters. *)
 
@@ -235,8 +235,8 @@ type parse_config =
 and parse_config_aux =
   Ocsigen_lib.Url.path -> parse_host -> parse_fun -> Xml.xml -> extension
 
-val register
-  :  name:string
+val register :
+   name:string
   -> ?fun_site:parse_config
   -> ?end_init:(unit -> unit)
   -> ?init_fun:(Xml.xml list -> unit)
@@ -256,7 +256,7 @@ val register
     [<extension>] and [</extension>]. This allows to give configuration options
     to extensions. If no function is supplied, the extension is supposed to
     accept no option (and loading will fail if an option is supplied)
-    See <<a_api module="Ocsigen_extensions.Configuration" | val process_elements >> for
+    See {!Configuration.process_elements} for
     the easy construction of such a function.
     - a function [exn_handler] that will create an error message from the
     exceptions that may be raised during the initialisation phase, and raise again
@@ -281,8 +281,8 @@ module Configuration : sig
   type attribute
   (** Specification of a XML attribute. *)
 
-  val element
-    :  name:string
+  val element :
+     name:string
     -> ?obligatory:bool
     -> ?init:(unit -> unit)
     -> ?elements:element list
@@ -304,8 +304,8 @@ module Configuration : sig
       @param other_attributes Optional function to be applied on the unspecfied attributes
   *)
 
-  val attribute
-    :  name:string
+  val attribute :
+     name:string
     -> ?obligatory:bool
     -> (string -> unit)
     -> attribute
@@ -315,8 +315,8 @@ module Configuration : sig
       @param f Function to be applied on the value string of the attribute
   *)
 
-  val process_element
-    :  in_tag:string
+  val process_element :
+     in_tag:string
     -> elements:element list
     -> ?pcdata:(string -> unit)
     -> ?other_elements:
@@ -333,8 +333,8 @@ module Configuration : sig
         and no function [other_elements] (resp. other_attributes) is provided
   *)
 
-  val process_elements
-    :  in_tag:string
+  val process_elements :
+     in_tag:string
     -> elements:element list
     -> ?pcdata:(string -> unit)
     -> ?other_elements:
@@ -386,8 +386,8 @@ val replace_user_dir : Re.Pcre.regexp -> ud_string -> string -> string
 exception Not_concerned
 (** {3 Regular expressions for redirections} *)
 
-val find_redirection
-  :  Re.Pcre.regexp
+val find_redirection :
+   Re.Pcre.regexp
   -> bool
   -> string
   -> Ocsigen_request.t
@@ -400,25 +400,27 @@ val compose : extension list -> extension_composite
 val make_parse_config : Ocsigen_lib.Url.path -> parse_config_aux -> parse_fun
 val parse_config_item : parse_config
 
-val site_ext
-  :  extension_composite
+val site_ext :
+   extension_composite
   -> Ocsigen_charset_mime.charset option
   -> Ocsigen_lib.Url.path
   -> extension
 
-val set_hosts : (virtual_hosts * config_info * extension_composite) list -> unit
+type host_config = virtual_hosts * config_info * extension_composite
+
+val set_hosts : host_config list -> unit
 val get_hosts : unit -> (virtual_hosts * config_info * extension_composite) list
 
-val compute_result
-  :  ?previous_cookies:Ocsigen_cookie_map.t
+val compute_result :
+   ?previous_cookies:Ocsigen_cookie_map.t
   -> Ocsigen_request.t
   -> Ocsigen_response.t Lwt.t
 (** Compute the answer to be sent to the client, by trying all
     extensions according the configuration file. *)
 
-val get_number_of_connected : unit -> int
-(** Profiling *)
+(** {3 Profiling} *)
 
+val get_number_of_connected : unit -> int
 val during_initialisation : unit -> bool
 val start_initialisation : unit -> unit
 val end_initialisation : unit -> unit
