@@ -51,4 +51,9 @@ val first_pass : Xml.xml list -> unit
 *)
 
 val later_pass : Xml.xml list -> unit
+
+(**/**)
+
 val parse_config : ?file:string -> unit -> Xml.xml list list
+(** Returns the config file. Use this if you want to read a config file from
+    your own executable. See {!Ocsigen_server.exec}.*)
